@@ -25,8 +25,14 @@ from fmdt.truth import (
     WATEC12_DIR,
     HumanDetection,
     read_human_detection_csv,
-    init_ground_truth
+    init_ground_truth,
+    GroundTruth
 )
 
 # from fmdt.truth import HumanDetection
 
+MAJOR_VERSION = 0
+MINOR_VERSION = 0
+PATCH         = 23
+
+VERSION = str(MAJOR_VERSION) + "." + str(MINOR_VERSION) + "." + str(PATCH)
